@@ -34,7 +34,7 @@ from sherlockpipe.transitresult import TransitResult
 from multiprocessing import Pool
 from scipy.signal import argrelextrema, savgol_filter
 from scipy.ndimage.interpolation import shift
-from scipy import stats
+from scipy import stats, signal
 from wotan import flatten
 from astropy.stats import sigma_clip
 
@@ -458,12 +458,14 @@ class Sherlock:
             logging.info('radius_max = %.6f', star_info.radius_max)
         if not star_info.radius_assumed and not star_info.mass_assumed and star_info.teff is not None:
             star_df = pandas.DataFrame(columns=['R_star', 'R_star_lerr', 'R_star_uerr', 'M_star', 'M_star_lerr',
-                                              'M_star_uerr', 'Teff_star', 'Teff_star_lerr', 'Teff_star_uerr'])
+                                              'M_star_uerr', 'Teff_star', 'Teff_star_lerr', 'Teff_star_uerr', 'ld_a',
+                                                'ld_b'])
             star_df = star_df.append({'R_star': star_info.radius, 'R_star_lerr': star_info.radius - star_info.radius_min,
                             'R_star_uerr': star_info.radius_max - star_info.radius,
                             'M_star': star_info.mass, 'M_star_lerr': star_info.mass - star_info.mass_min,
                             'M_star_uerr': star_info.mass_max - star_info.mass,
-                            'Teff_star': star_info.teff, 'Teff_star_lerr': 200, 'Teff_star_uerr': 200},
+                            'Teff_star': star_info.teff, 'Teff_star_lerr': 200, 'Teff_star_uerr': 200,
+                                      'ld_a': star_info.ld_coefficients[0], 'ld_b': star_info.ld_coefficients[1]},
                            ignore_index=True)
             star_df.to_csv(object_dir + "params_star.csv", index=False)
         logging.info('================================================')
@@ -633,6 +635,10 @@ class Sherlock:
         if is_short_cadence and self.initial_smooth:
             logging.info('Applying Savitzky-Golay filter')
             clean_flux = savgol_filter(clean_flux, 11, 3)
+            flux_filter = flux - np.ones(len(clean_flux))
+            filter = signal.butter(2, 12, btype='lp', fs=720, analog=False, output='sos')
+            flux_filter = signal.sosfiltfilt(filter, flux_filter)
+            clean_flux = flux_filter + np.ones(len(clean_flux))
             #clean_flux = uniform_filter1d(clean_flux, 11)
             #clean_flux = self.flatten_bw(self.FlattenInput(clean_time, clean_flux, 0.02))[0]
         return clean_time, clean_flux, clean_flux_err
